[![DOI](https://zenodo.org/badge/254798322.svg)](https://zenodo.org/badge/latestdoi/254798322)


# Summary
A python wrapper for https://github.com/JanZrimec/DNA_melting_bubbles_TIDD


# Dependency

- pandas

- matlab

- java


# Installation

`pip install pyDNA-melting`

OR 

`python setup.py install`

# Usage

Any sequence long than 10bp

`DNA_melting -s AAAAAAAAAGTGTGTAA`


